@@ -119,10 +119,14 @@ int main()
     cout << "Sending notification..." << endl;
     C.perform(Notify(Trig.name()));
 
+    int notifs = 0;
     for (int i=0; (i < 20) && !Trig.Done(); ++i)
     {
+      if (notifs)
+	throw logic_error("Got " + to_string(notifs) + " "
+	    "unexpected notifications!");
       Sleep(500);
-      C.get_notifs();
+      notifs = C.get_notifs();
       cout << ".";
     }
     cout << endl;
@@ -132,6 +136,8 @@ int main()
       cout << "No notification received!" << endl;
       return 1;
     }
+    if (notifs != 1)
+      throw logic_error("Expected 1 notification, got " + to_string(notifs));
   }
   catch (const sql_error &e)
   {
